import axios from 'axios'
// import storage from 'store'
import router from '../router'
import {
	Message
} from 'element-ui';
// 创建 axios 实例
const Url = "https://pcode.baozhida.cn"
const request = axios.create({
	// API 请求的默认前缀
	baseURL: process.env.NODE_ENV === 'production' ? Url : '/API',
	timeout: 6000, // 请求超时时间
	withCredentials: false,
	headers: {
		'Content-Type': 'application/json',
		'Access-Control-Allow-Origin': '*'
	}
})

// 异常拦截处理器
const errorHandler = (error) => {
	if (error.response) {
		const data = error.response.data
		if (error.response.status === 403) {
			Message.error(data.message)
		}
		if (error.response.status === 401) {
			Message.error(data.message)
		}
	}
	return Promise.reject(error)
}

// request interceptor
request.interceptors.request.use(config => {
	const token = localStorage.getItem('T_tokey')
	// 让每个请求携带自定义 token 请根据实际情况自行修改
	if (token) {
		config.headers.Authorization = 'Bearer ' + token
	}
	return config
}, errorHandler)

// response interceptor
request.interceptors.response.use((response) => {
	if (response.data.Code || response.data.code) {
		const res = response.data
		if (res.Code == 200 || res.code == 200 || res.code == 404) {
			return res
		} else {
			Message.error(res.Msg || res.message)
		}
		return response.data
	} else {
		return response.data
	}
}, errorHandler)

export default request

export {
	request as axios
}